==> kubernetes-model-1.0.30-sources.jar: io/fabric8/kubernetes/api/model/EventSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class EventSourceFluentImpl<T extends EventSourceFluent<T>> extends BaseFluent<T> implements EventSourceFluent<T>{

     String component;     String host;     Map<String, Object> additionalProperties = new HashMap();

    public String getComponent(){
    return this.component;
    }
    public T withComponent( String component){
    this.component=component; return (T) this;
    }
    public String getHost(){
    return this.host;
    }
    public T withHost( String host){
    this.host=host; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
EventSourceFluentImpl that = (EventSourceFluentImpl) o;
if (component != null ? !component.equals(that.component) :that.component != null) return false;
if (host != null ? !host.equals(that.host) :that.host != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.43-sources.jar: io/fabric8/kubernetes/api/model/EventSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class EventSourceFluentImpl<T extends EventSourceFluent<T>> extends BaseFluent<T> implements EventSourceFluent<T>{

     String component;     String host;     Map<String, Object> additionalProperties = new HashMap();
public EventSourceFluentImpl(){
    
}
public EventSourceFluentImpl( EventSource instance ){
    this.withComponent(instance.getComponent()); this.withHost(instance.getHost()); 
}

    public String getComponent(){
    return this.component;
    }
    public T withComponent( String component){
    this.component=component; return (T) this;
    }
    public String getHost(){
    return this.host;
    }
    public T withHost( String host){
    this.host=host; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
EventSourceFluentImpl that = (EventSourceFluentImpl) o;
if (component != null ? !component.equals(that.component) :that.component != null) return false;
if (host != null ? !host.equals(that.host) :that.host != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
